@@ -247,7 +247,6 @@ class OJMixin(object):
 
     def login(self):
         url = self.url + '/accounts/login/'
-        name = {'name': 'csrfmiddlewaretoken'}
         username = raw_input('Username: ')
         password = getpass.getpass()
 
@@ -260,8 +259,8 @@ class OJMixin(object):
             'password': password,
             'csrfmiddlewaretoken': self.session.cookies.get('csrftoken')
         }
+        self.session.post(url, data, headers=headers)
 
-        resp = self.session.post(url, data, headers=headers)
         if self.session.cookies.get('LEETCODE_SESSION'):
             self.loggedIn = True
             print 'Welcome %s!' % username
@@ -447,7 +446,7 @@ class OJMixin(object):
         for s in re.findall(js, resp.text, re.DOTALL):
             v = execjs.eval(s)
             try:
-                df = json.loads(v.get('distribution_formatted'))
+                df = json.loads(v.get('runtimeDistributionFormatted'))
                 if df.get('lang') == self.lang:
                     for e in df.get('distribution')[: limit]:
                         t = int(e[0])
@@ -470,7 +469,7 @@ class OJMixin(object):
         for s in re.findall(js, resp.text, re.DOTALL):
             v = execjs.eval(s)
             try:
-                df = json.loads(v.get('distribution_formatted'))
+                df = json.loads(v.get('runtimeDistributionFormatted'))
                 if df.get('lang') == self.lang:
                     for t, p in df.get('distribution'):
                         runtimes.append((int(t), float(p)))
@@ -922,16 +921,16 @@ Commands and options can be completed by <TAB>."""
                 r = 0
                 for i in xrange(len(times)):
                     t1, p = times[i]
-                    if t1 <= t:
+                    if t1 >= t:
                         times[i] = (str(t1) + '*', p)
                         break
                     else:
                         r += p
 
                 g = Pyasciigraph(graphsymbol='*')
-                for L in g.graph('Runtime' + 66 * ' ' + '%  ms', times[:-limit:-1]):
+                for L in g.graph('Runtime' + 66 * ' ' + '%  ms', times[1:limit]):
                     print L
-                print 'Rank: %.2f%%' % (100 - r)
+                print 'Rank: %.2f%%' % r
             except ImportError:
                 pass
 
